Module: RemotelyExceptional::Handlers::PrioritizedHandler

Defined in:
lib/remotely_exceptional/handlers/prioritized_handler.rb

Defined Under Namespace

Modules: ClassMethods

Constant Summary collapse

DEFAULT_PRIORITY =

The default priority that should be used when registering handlers.

1000.freeze
HASH_BUILDER =

Hash#default_proc for hashes that should return a new Set if a given key is not defined.

lambda { |hash, key| hash[key] = Set.new }.freeze

Class Method Summary collapse

Class Method Details

.included(includer) ⇒ Object



9
10
11
# File 'lib/remotely_exceptional/handlers/prioritized_handler.rb', line 9

def self.included(includer)
  includer.extend(ClassMethods)
end